#!/bin/sh
# SPDX-License-Identifier: MIT
# Copyright (C) 2019 Beckhoff Automation GmbH & Co. KG

. /usr/local/bin/shlib/add_or_replace_in.sh
. /usr/local/bin/shlib/std.sh

if [ $(id -u) -ne 0 ]; then
	throw "Usage: run '$0' as root.\n"
fi

# an empty poudriere.conf allows us to detect, if we are running for the first time
touch /usr/local/etc/poudriere.conf

# switch to experimental repository
/bin/sh /usr/local/share/examples/bhf/pkgrepo-set.sh experimental

# install some useful tools
env ASSUME_ALWAYS_YES=YES pkg install \
	TwinCAT-SDK-internal_4024 \
	bash \
	cmake \
	fish \
	fusefs-sshfs \
	gcc \
	gdb \
	git \
	htop \
	jevops-internal \
	joe \
	jq \
	llvm \
	neovim \
	openfortivpn \
	os-generic-userland-devtools \
	poudriere-trueos \
	rsync \
	samba412 \
	src \
	tmux \
	wget \
	xmlstarlet

# weaken sshd_config to allow Microsoft ssh tools to connect ...
sed -i -e 's/^Ciphers/#Ciphers/g' /etc/ssh/sshd_config
sed -i -e 's/^HostKeyAlgorithms/#HostKeyAlgorithms/g' /etc/ssh/sshd_config
sed -i -e 's/^KexAlgorithms/#KexAlgorithms/g' /etc/ssh/sshd_config
sed -i -e 's/^MACs/#MACs/g' /etc/ssh/sshd_config
sed -i -e 's/#PasswordAuthentication no/PasswordAuthentication yes/g' /etc/ssh/sshd_config
service sshd restart

# generate some symlinks
if ! test -x /usr/local/bin/vim; then
	ln -s /usr/local/bin/nvim /usr/local/bin/vim
fi
ln -s /usr/local/bin/gdb /usr/bin/gdb

# enable and allow users to fuse mount to enable remote directories over ssh or samba
pw groupmod operator -m Administrator
kldload fuse
sysctl vfs.usermount=1

# make the above changes permanent
add_or_replace_in /boot/loader.conf 'fuse_load=' '"YES"'
add_or_replace_in /etc/sysctl.conf 'vfs.usermount=' '"1"'

# allow Administrator to use doas without password
sed -i -e 's/^permit Administrator/permit nopass Administrator/' /usr/local/etc/doas.conf

# set SU_CMD used for builds within ports tree
if ! grep 'export SU_CMD;' /usr/home/Administrator/.shrc; then
	echo 'SU_CMD="/usr/local/bin/doas /bin/sh -c"; export SU_CMD;' >> /usr/home/Administrator/.shrc
fi

# increase NTP update rate
add_or_replace_in /etc/ntp.conf 'pool ' 'ntp.beckhoff-cloud.com iburst minpoll 7 maxpoll 8'

# enable git-completion
ln -s /usr/local/share/git-core/contrib/completion/git-completion.bash /usr/home/Administrator/.git-completion.bash
ln -s /usr/local/share/git-core/contrib/completion/git-completion.tcsh /usr/home/Administrator/.git-completion.tcsh
add_or_replace_in /usr/home/Administrator/.cshrc 'source ~/.git-completion.tcsh' ""

# enable german keyboard layout
add_or_replace_in /etc/rc.conf 'keymap=' '"de.noacc.kbd"'
kbdcontrol -l de.noacc.kbd

# disable boot_mute to allow DDB
sed -i -e 's/^boot_mute=/#&/' /boot/loader.conf

# reenable keyboard shortcuts f.e. "CTRL+ALT+DEL"
sysctl kern.vt.kbd_debug=1
sysctl kern.vt.kbd_halt=1
sysctl kern.vt.kbd_panic=1
sysctl kern.vt.kbd_poweroff=1
sysctl kern.vt.kbd_reboot=1

# make the above changes permanent
add_or_replace_in /etc/sysctl.conf 'kern.vt.kbd_debug=' '"1"'
add_or_replace_in /etc/sysctl.conf 'kern.vt.kbd_halt=' '"1"'
add_or_replace_in /etc/sysctl.conf 'kern.vt.kbd_panic=' '"1"'
add_or_replace_in /etc/sysctl.conf 'kern.vt.kbd_poweroff=' '"1"'
add_or_replace_in /etc/sysctl.conf 'kern.vt.kbd_reboot=' '"1"'

# enable developer helpers in make.conf
echo DEVELOPER=yes >> /etc/make.conf

# prepare poudriere, but don't mess up existing configurations. That's why we created an empty
# poudriere.conf at the beginning
if ! test -s /usr/local/etc/poudriere.conf; then
	sed "s/^#ZPOOL/ZPOOL/" /usr/local/etc/poudriere.conf.sample > /usr/local/etc/poudriere.conf
fi
mkdir -p /usr/local/poudriere
mkdir -p /usr/ports/distfiles
